/* anameal.h */

/*
    NUT nutrition software 
    Copyright (C) 1996-2014 by Jim Jozwiak.

    This program is free software; you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation; either version 2 of the License, or
    (at your option) any later version.

    This program is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with this program; if not, write to the Free Software
    Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139, USA.
*/

#ifndef ANAMEAL_H
#define ANAMEAL_H

#include "options.h"

#ifdef __cplusplus
extern "C" {
#endif
 
void analyze_meals(struct meal *meal_ptr, int specialheader);
void deficsort(float *, int *, int);
int random_max_var_array(float [], int);
void thestory(const char *);

#ifdef __cplusplus
} /* closing brace for extern "C" */
#endif

#endif
